## Objective

Run [isort](https://pycqa.github.io/isort/) on your Python code to automatically sort and organize
your imports. isort separates imports into sections and by type. It's a helpful tool to ensure that
your code remains clean and readable.

### Global Configuration of isort

To add configuration to `isort` shared with any other usage of isort (such as manual run,
pre-commit, etc), you can use `pyproject.toml` configuration file or a dedicated `.isort.cfg`. Learn
more about [isort configuration](https://pycqa.github.io/isort/docs/configuration/config_files.html)
files.

Here's an example configuration for `pyproject.toml`:

```toml
[tool.isort]
profile = "black"
line_length = 100
```

And for `.isort.cfg`:

```cfg
[settings]
profile=hug
line_length=100
```

These examples set the line length to 100 characters and use the "black" profile, which is designed
to work well with the `black` auto-formatter.

## How to use it

1. Configure the `pyproject.toml` or `.isort.cfg` file in your repository's root directory with your
   desired rules.
2. Include the isort template in your CI/CD configuration (see quick use above).
3. If you need to customize the job, check
   the [jobs customization](https://docs.r2devops.io/get-started/use-templates/#job-templates-customization).

## Add an <a href="https://pycqa.github.io/isort/"><img alt="Imports: isort" src="https://img.shields.io/badge/Imports-isort-yellow"></a> Badge to your project README.md

To display the use of isort in your project, you can add the following badge to your README.md:

```markdown
<a href="https://pycqa.github.io/isort/">
    <img alt="Imports: isort" src="https://img.shields.io/badge/Imports-isort-yellow">
</a>
```
